<?php
  /* vim: set expandtab tabstop=4 softtabstop=4 shiftwidth=4:
  Codificación: UTF-8
  +----------------------------------------------------------------------+
  | Elastix version 1.6-5                                               |
  | http://www.elastix.org                                               |
  +----------------------------------------------------------------------+
  | Copyright (c) 2006 Palosanto Solutions S. A.                         |
  +----------------------------------------------------------------------+
  | Cdla. Nueva Kennedy Calle E 222 y 9na. Este                          |
  | Telfs. 2283-268, 2294-440, 2284-356                                  |
  | Guayaquil - Ecuador                                                  |
  | http://www.palosanto.com                                             |
  +----------------------------------------------------------------------+
  | The contents of this file are subject to the General Public License  |
  | (GPL) Version 2 (the "License"); you may not use this file except in |
  | compliance with the License. You may obtain a copy of the License at |
  | http://www.opensource.org/licenses/gpl-license.php                   |
  |                                                                      |
  | Software distributed under the License is distributed on an "AS IS"  |
  | basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See  |
  | the License for the specific language governing rights and           |
  | limitations under the License.                                       |
  +----------------------------------------------------------------------+
  | The Original Code is: Elastix Open Source.                           |
  | The Initial Developer of the Original Code is PaloSanto Solutions    |
  +----------------------------------------------------------------------+
  $Id: paloSantoDocumentViewer.class.php,v 1.1 2009-06-17 06:06:06 Alex Villacís Lasso a_villacis@palosanto.com Exp $ */

/*
CREATE TABLE docrepo
(
    id_documento    INTEGER     NOT NULL, 
    id_conferencia  INTEGER     NOT NULL,
    nombre_doc      varchar(128)    NOT NULL,
    mime_type       varchar(64) NOT NULL,
    nombre_original varchar(128)    NOT NULL, 
    fecha_upload    datetime    NOT NULL,
    id_invitado_upload int      NOT NULL,

    PRIMARY KEY (id_documento),
    FOREIGN KEY (id_conferencia) REFERENCES conferencia(id_conferencia),
    FOREIGN KEY (id_invitado_upload)    REFERENCES invitado(id_invitado)
);
*/
class paloSantoDocumentRepository {
    var $_DB;
    var $errMsg;
    private $idConf;
    private $sDirDocRepo;

    function paloSantoDocumentRepository(&$pDB, $idConf, $sDirBase)
    {
        $this->errMsg = '';
        // Se recibe como parámetro una referencia a una conexión paloDB
        if (is_object($pDB)) {
            $this->_DB =& $pDB;
            $this->errMsg = $this->_DB->errMsg;
        } else {
            $dsn = (string)$pDB;
            $this->_DB = new paloDB($dsn);

            if (!$this->_DB->connStatus) {
                $this->errMsg = $this->_DB->errMsg;
                // debo llenar alguna variable de error
            }
        }
        if ($this->errMsg == '') {
            // Conexión exitosa. Se procede a construir el nombre del 
            // directorio del repositorio y purgar los documentos que ya
            // no existan
            $this->sDirDocRepo = $sDirBase.'/conferencia-docrepo-'.$idConf;
            $this->idConf = $idConf;
            if (!is_dir($this->sDirDocRepo)) {
                if (!mkdir($this->sDirDocRepo, 0755)) {
                    $this->errMsg = 'Unable to create conference directory!';
                }
            }
            $this->_purgarDocsInvalidos();
        }
    }

    private function _rutaDoc($sNombreDoc) { return $this->sDirDocRepo.'/'.$sNombreDoc; }

    // Purgar del repositorio todos los documentos que hayan sido borrados 
    // externamente, para mantener consistencia con la base de datos.
    private function _purgarDocsInvalidos()
    {
        $sql = 'SELECT id_documento, nombre_doc FROM docrepo WHERE id_conferencia = ?';
        $listaDoc = $this->_DB->fetchTable($sql, TRUE, array($this->idConf));
        if (!is_array($listaDoc)) {
            $this->errMsg = "Unable to fetch document list - ".$this->_DB->errMsg;
        } else {
            foreach ($listaDoc as $tuplaDoc) {
                if (!file_exists($this->_rutaDoc($tuplaDoc['nombre_doc']))) {
                    // Archivo ha sido borrado externamente. Se quita entrada de docrepo.
                    $sql = 'DELETE FROM docrepo WHERE id_conferencia = ? AND id_documento = ?';
                    $bExito = $this->_DB->genQuery($sql, array($this->idConf, $tuplaDoc['id_documento']));
                    if (!$bExito) {
                        $this->errMsg = 'Unable to remove entry for invalid document - '.$this->_DB->errMsg;
                    }
                }
            }
        }
    }

    function getDocumentList()
    {
        $sql = 
            'SELECT id_documento, docrepo.id_conferencia AS id_conferencia, nombre_doc, '.
                'nombre_original, fecha_upload, mime_type, '.
                'docrepo.id_invitado_upload AS id_invitado, invitado.nick AS nick '.
            'FROM docrepo, invitado '.
            'WHERE docrepo.id_conferencia = invitado.id_conferencia '.
                'AND docrepo.id_invitado_upload = invitado.id_invitado '.
                'AND docrepo.id_conferencia = ? '.
            'ORDER BY nombre_doc';
        $listaDoc = $this->_DB->fetchTable($sql, TRUE, array($this->idConf));
        if (is_array($listaDoc)) {
            return $listaDoc;
        } else {
            $infoDoc = NULL;
            $this->errMsg = "Unable to fetch document list - ".$this->_DB->errMsg;
        }
    }
    
    function registerUploadDoc($fileInfo, $id_invitado, &$idNuevoDoc)
    {
        // Nombre de archivo dentro de repositorio
        $sRutaNueva = tempnam($this->sDirDocRepo, 'docrepo-');
        $sNombreNuevo = substr($sRutaNueva, strlen($this->sDirDocRepo) + 1);
        if (!move_uploaded_file($fileInfo['tmp_name'], $sRutaNueva)) {
            $this->errMsg = 'Unable to move uploaded file into repository.';
            return FALSE;
        }
        $sFechaUpload = date('Y-m-s H:i:s');
        $sql = 
            'INSERT INTO docrepo (id_conferencia, nombre_doc, nombre_original, fecha_upload, id_invitado_upload, mime_type) '.
            'VALUES (?, ?, ?, ?, ?, ?)';
        $resultado = $this->_DB->genQuery($sql, 
            array($this->idConf, $sNombreNuevo, $fileInfo['name'], $sFechaUpload, $id_invitado, $fileInfo['type']));
        if (!$resultado) {
            unlink($sRutaNueva);
            $this->errMsg = 'Unable to register uploaded file in repository - '.$this->_DB->errMsg;
            return FALSE;
        } else {
            $sql = 
                'SELECT id_documento FROM docrepo '.
                'WHERE id_conferencia = ? AND nombre_doc = ? '.
                    'AND nombre_original = ? AND fecha_upload = ? '.
                    'AND id_invitado_upload = ?';
            $tupla = $this->_DB->getFirstRowQuery($sql, FALSE, 
                array($this->idConf, $sNombreNuevo, $fileInfo['name'], $sFechaUpload, $id_invitado));
            if (!is_array($tupla)) {
                $this->errMsg = 'Could not recover ID of registered document - '.$this->_DB->errMsg;
                return FALSE;
            } elseif (count($tupla) <= 0) {
                $this->errMsg = 'Could not recover ID of registered document - not found';
                return FALSE;
            } else {
                $idNuevoDoc =  $tupla[0];
            }
        }
        return TRUE;
    }

    function readDocumentContent($id_documento)
    {
        $sql = 'SELECT nombre_doc, nombre_original, mime_type FROM docrepo WHERE id_conferencia = ? AND id_documento = ?';
        $tupla = $this->_DB->getFirstRowQuery($sql, TRUE, array($this->idConf, $id_documento));
        if (!is_array($tupla)) {
            $this->errMsg = 'Could not locate document in repository - '.$this->_DB->errMsg;
            return NULL;
        } elseif (count($tupla) <= 0) {
            $this->errMsg = 'Could not locate document in repository by ID';
            return NULL;
        } else {
            $sRutaDoc = $this->_rutaDoc($tupla['nombre_doc']);
            if (!file_exists($sRutaDoc)) {
                $this->errMsg = 'Document was deleted externally.';
                return FALSE;
            }
            header("Cache-Control: private");
            header("Pragma: cache");
//            header("Content-Type: application/octet-stream\n");
            Header('Content-Type: '.$tupla['mime_type']);
            header("Content-Disposition: attachment; filename=$tupla[nombre_original]"); 
            $sContenido = file_get_contents($sRutaDoc);
        }
        return $sContenido;
    }
    
    function deleteUploadDoc($id_documento)
    {
        $sql = 'SELECT nombre_doc FROM docrepo WHERE id_conferencia = ? AND id_documento = ?';
        $tupla = $this->_DB->getFirstRowQuery($sql, TRUE, array($this->idConf, $id_documento));
        if (!is_array($tupla)) {
            $this->errMsg = 'Could not locate document in repository - '.$this->_DB->errMsg;
            return FALSE;
        } elseif (count($tupla) <= 0) {
            $this->errMsg = 'Could not locate document in repository by ID';
            return FALSE;
        } else {
            $sRutaDoc = $this->_rutaDoc($tupla['nombre_doc']);
            if (file_exists($sRutaDoc)) {
                $bExito = unlink($sRutaDoc);
                if (!$bExito) {
                    $this->errMsg = 'Unable to remove document from filesystem';
                    return FALSE;
                }
            }
            $sql = 'DELETE FROM docrepo WHERE id_conferencia = ? AND id_documento = ?';
            $bExito = $this->_DB->genQuery($sql, array($this->idConf, $id_documento));
            if (!$bExito) {
                $this->errMsg = 'Unable to remove entry for document - '.$this->_DB->errMsg;
                return FALSE;
            }
            return TRUE;
            
        }
    }
}

