<?php
  /* vim: set expandtab tabstop=4 softtabstop=4 shiftwidth=4:
  Codificación: UTF-8
  +----------------------------------------------------------------------+
  | Elastix version 1.6-5                                               |
  | http://www.elastix.org                                               |
  +----------------------------------------------------------------------+
  | Copyright (c) 2006 Palosanto Solutions S. A.                         |
  +----------------------------------------------------------------------+
  | Cdla. Nueva Kennedy Calle E 222 y 9na. Este                          |
  | Telfs. 2283-268, 2294-440, 2284-356                                  |
  | Guayaquil - Ecuador                                                  |
  | http://www.palosanto.com                                             |
  +----------------------------------------------------------------------+
  | The contents of this file are subject to the General Public License  |
  | (GPL) Version 2 (the "License"); you may not use this file except in |
  | compliance with the License. You may obtain a copy of the License at |
  | http://www.opensource.org/licenses/gpl-license.php                   |
  |                                                                      |
  | Software distributed under the License is distributed on an "AS IS"  |
  | basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See  |
  | the License for the specific language governing rights and           |
  | limitations under the License.                                       |
  +----------------------------------------------------------------------+
  | The Original Code is: Elastix Open Source.                           |
  | The Initial Developer of the Original Code is PaloSanto Solutions    |
  +----------------------------------------------------------------------+
  $Id: paloSantoDocumentViewer.class.php,v 1.1 2009-06-17 06:06:06 Alex Villacís Lasso a_villacis@palosanto.com Exp $ */
class paloSantoDocumentViewer {
    var $_DB;
    var $errMsg;

    function paloSantoDocumentViewer(&$pDB)
    {
        // Se recibe como parámetro una referencia a una conexión paloDB
        if (is_object($pDB)) {
            $this->_DB =& $pDB;
            $this->errMsg = $this->_DB->errMsg;
        } else {
            $dsn = (string)$pDB;
            $this->_DB = new paloDB($dsn);

            if (!$this->_DB->connStatus) {
                $this->errMsg = $this->_DB->errMsg;
                // debo llenar alguna variable de error
            } else {
                // debo llenar alguna variable de error
            }
        }
    }

    function getDocumentList($idConf)
    {
        $listaOpcionesDoc = NULL;
        $listaDoc = $this->_DB->fetchTable(
            'SELECT id_documento, nombre_doc FROM documento WHERE id_conferencia = ? ORDER BY nombre_doc',
            FALSE, 
            array($idConf));
        if (is_array($listaDoc)) {
            $listaOpcionesDoc = array();
            foreach ($listaDoc as $tuplaDoc) {
                $listaOpcionesDoc[$tuplaDoc[0]] = $tuplaDoc[1];
            }            
        } else {
            $infoDoc = NULL;
            $this->errMsg = "Unable to fetch document list - ".$this->_DB->errMsg;
        }
        return $listaOpcionesDoc;
    }
    
    function getDocumentInfo($idConf, $idDoc)
    {
        $infoDoc = $this->_DB->getFirstRowQuery('SELECT * FROM documento WHERE id_conferencia = ? AND id_documento = ?', TRUE, array($idConf, $idDoc));
        if (is_array($infoDoc)) {
            if (count($infoDoc) == 0) {
                $this->errMsg = "Specified document does not exist.";
                $infoDoc = NULL;
            } elseif (!is_dir($infoDoc['ruta_directorio_imgs'])) {
                $this->errMsg = "Document directory is invalid.";
                $infoDoc = NULL;
            }
        } else {
            $infoDoc = NULL;
            $this->errMsg = "Unable to fetch document info - ".$this->_DB->errMsg;
        }
        return $infoDoc;
    }

    /**
     * Procedimiento para procesar el archivo de subida con unoconv
     *
     * @return bool VERDADERO si la conversión tiene éxito, o FALSO si falla
     */
    function processUploadedFile($fileInfo, $sDirCache, $idConf, &$idNuevoDoc)
    {
        if (!is_dir($sDirCache)) {
            $this->errMsg = 'Invalid base directory for document image files.';
            return FALSE;
        }

        // Verificar si el nombre de archivo tiene una extensión definida
        if (!ereg('^(.*)\.[[:alnum:]]+$', $fileInfo['name'])) {
            $this->errMsg = 'Cannot identify document extension for conversion.';
            return FALSE;
        }
        
        // Se intenta construir un nombre único de directorio debajo del directorio 
        // base.
        $sNombreUnico = sprintf('%d-%s-dir', time(), basename($fileInfo['tmp_name']));
        $sDirCompleto = "$sDirCache/$sNombreUnico";
        if (!mkdir($sDirCompleto))
        {
            $this->errMsg = 'Unable to create directory '.$sDirCompleto.' for document images.';
            return FALSE;
        }
        
        // Se intenta cambiar el nombre del archivo de vuelta a el nombre que
        // tenía originalmente, con un prefijo. Esto se debe a que unoconv 
        // toma en cuenta la extensión del archivo para determinar el formato
        // fuente a convertir.
        $sNombreSinEspacios = strtr($fileInfo['name'], ' ', '_');
        $sNombreDoc = sprintf('%s-%s', $fileInfo['tmp_name'], $sNombreSinEspacios);
        $bExito = move_uploaded_file($fileInfo['tmp_name'], $sNombreDoc);
        if (!$bExito) {
            $this->errMsg = 'Unable to rename file before conversion to PDF.';
            return FALSE;
        }
        $regs = NULL;
        ereg('^(.*)\.[[:alnum:]]+', $sNombreDoc, $regs);
        $sNombrePDF = $regs[1].".pdf";
        
        // Invocar unoconv con el archivo recién renombrado...
        $output = array();
        $retval = NULL;
        putenv("HOME=/tmp");    // unoconv requiere acceso de escritura al directorio apuntado por HOME
        exec("unoconv -c 'socket,host=localhost,port=2002;urp;StarOffice.ComponentContext' -f pdf ".escapeshellarg($sNombreDoc)." > /tmp/unoconv-exec.txt 2>&1", $output, $retval);        
        if (!file_exists($sNombrePDF)) {
            $this->errMsg = "Document conversion to PDF failed - ".join(' ', $output);
            $bExito = FALSE;
        }
        
        // Invocar 'convert' sobre el archivo PDF. Si el archivo de salida se
        // invoca como image.jpg, la salida será generada como image-[0..N].jpg
        // TODO: parametrizar tamaño final de la imagen.
        if ($bExito) {
            exec("convert -auto-orient -density 100 -geometry 1024x2048 ".escapeshellarg($sNombrePDF)." $sDirCompleto/image.jpg 2>&1", $output, $retval);
            if (!file_exists("$sDirCompleto/image-0.jpg") && !file_exists("$sDirCompleto/image.jpg")) {
                $this->errMsg = "PDF conversion to JPG failed - ".join(' ', $output);
                $bExito = FALSE;
            }
        }

        // Contar el número de archivos que fueron generados para poder paginar correctamente.
        $iNumPaginas = 0;
        if ($bExito) {
            $hDir = opendir($sDirCompleto);
            if (!$hDir) {
                $this->errMsg = "Unable to inspect output directory for slideshow files!";
                $bExito = FALSE;
            } else {
                while (false !== ($sNombre = readdir($hDir))) {
                    if (ereg('^image(-[[:digit:]]+)?\.jpg$', $sNombre)) $iNumPaginas++;
                }
                closedir($hDir);
                if ($iNumPaginas <= 0) {
                    $this->errMsg = "(internal) Failed to identify image files in output directory!";
                    $bExito = FALSE;
                }
            }
        }
        
        // Ahora se puede insertar la información del documento en la base de datos
        if ($bExito) {
            $sqlInsercionArchivo = 
                'INSERT INTO documento (nombre_doc, id_conferencia, ruta_directorio_imgs, num_paginas) '.
                'VALUES (?, ?, ?, ?)';
            $bExito =& $this->_DB->genQuery($sqlInsercionArchivo, 
                array($fileInfo['name'], $idConf, $sDirCompleto, $iNumPaginas));
            if (!$bExito) {
                $this->errMsg = "Could not store document information: ".$pDB->errMsg;
            } else {
                $sqlPeticionID = 
                    'SELECT id_documento FROM documento '.
                    'WHERE nombre_doc = ? AND id_conferencia = ? '.
                        'AND ruta_directorio_imgs = ? AND num_paginas = ? '.
                    'ORDER BY id_documento DESC';
                $tupla = $this->_DB->getFirstRowQuery($sqlPeticionID, FALSE, 
                    array($fileInfo['name'], $idConf, $sDirCompleto, $iNumPaginas));
                if (!is_array($tupla)) {
                    $this->errMsg = "Could not fetch new document ID: ".$pDB->errMsg;
                    $bExito = FALSE;
                } elseif (count($tupla) <= 0) {
                    $this->errMsg = "(internal) Could not locate newly saved document information!";
                    $bExito = FALSE;
                } else {
                    $idNuevoDoc = $tupla[0];
                }
            }
        }
        
        // Borrar los archivos temporales generados
        @unlink($sNombreDoc);
//        @unlink($sNombrePDF);
        return $bExito;
    }

    function deleteDocument($idConf, $idDoc)
    {
        $bContinuar = TRUE;
        $infoDoc = $this->getDocumentInfo($idConf, $idDoc);
        if (!is_array($infoDoc)) {
            $this->errMsg = 'Document information not found by ID';
            return FALSE;
        } else {
            // TODO: verificar resultado de exec
            exec('rm -rf '.escapeshellarg($infoDoc['ruta_directorio_imgs']));
            
            $bContinuar = $this->_DB->genQuery('DELETE FROM presentacion WHERE id_documento = ?', array($idDoc));
            if (!$bContinuar) $this->errMsg = $this->_DB->errMsg;
            if ($bContinuar) {
                $bContinuar = $this->_DB->genQuery('DELETE FROM documento WHERE id_documento = ?', array($idDoc));
                if (!$bContinuar) $this->errMsg = $this->_DB->errMsg;
            }
        }
        return $bContinuar;
    }

}
?>
