<?php
  /* vim: set expandtab tabstop=4 softtabstop=4 shiftwidth=4:
  Codificación: UTF-8
  +----------------------------------------------------------------------+
  | Elastix version 1.6-5                                               |
  | http://www.elastix.org                                               |
  +----------------------------------------------------------------------+
  | Copyright (c) 2006 Palosanto Solutions S. A.                         |
  +----------------------------------------------------------------------+
  | Cdla. Nueva Kennedy Calle E 222 y 9na. Este                          |
  | Telfs. 2283-268, 2294-440, 2284-356                                  |
  | Guayaquil - Ecuador                                                  |
  | http://www.palosanto.com                                             |
  +----------------------------------------------------------------------+
  | The contents of this file are subject to the General Public License  |
  | (GPL) Version 2 (the "License"); you may not use this file except in |
  | compliance with the License. You may obtain a copy of the License at |
  | http://www.opensource.org/licenses/gpl-license.php                   |
  |                                                                      |
  | Software distributed under the License is distributed on an "AS IS"  |
  | basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See  |
  | the License for the specific language governing rights and           |
  | limitations under the License.                                       |
  +----------------------------------------------------------------------+
  | The Original Code is: Elastix Open Source.                           |
  | The Initial Developer of the Original Code is PaloSanto Solutions    |
  +----------------------------------------------------------------------+
  $Id: paloSantoCreateConference.class.php,v 1.1 2009-06-29 08:06:40 Alex Villacís Lasso a_villacis@palosanto.com Exp $ */

class paloSantoCreateConference {
    var $_DB;
    var $errMsg;

    function paloSantoCreateConference(&$pDB)
    {
        // Se recibe como parámetro una referencia a una conexión paloDB
        if (is_object($pDB)) {
            $this->_DB =& $pDB;
            $this->errMsg = $this->_DB->errMsg;
        } else {
            $dsn = (string)$pDB;
            $this->_DB = new paloDB($dsn);

            if (!$this->_DB->connStatus) {
                $this->errMsg = $this->_DB->errMsg;
                // debo llenar alguna variable de error
            } else {
                // debo llenar alguna variable de error
            }
        }
    }

    /**
     * Método que crea una nueva conferencia de presentaciones. Se requiere lo 
     * siguiente para crear una conferencia. La conferencia se crea SIN INVITADOS.
     * Para agregar nuevos invitados, se debe usar el método agregarInvitadoConferencia()
     *
     * @param   $sNombre    string  Nombre de la conferencia
     * @param   $sTema      string  Tema de la conferencia
     * @param   $iHorasDuracion int Número de horas de duración
     * @param   $idConf     int(OUT) ID de la nueva conferencia creada
     * 
     * @return bool VERDADERO en éxito, FALSO en error. Si tiene éxito la creación,
     * se asigna idConf al ID de la conferencia para manipulación futura.
     */
    function createConference($sNombre, $sTema, $iHorasDuracion, &$idConf, $id_cbmysql_conference = NULL)
    {
        $this->errMsg = '';
        if (trim($sNombre) == '') {
            $this->errMsg = 'New conference must have non-empty name.';
            return FALSE;
        } elseif (trim($sTema) == '') {
            $this->errMsg = 'New conference must have non-empty subject.';
            return FALSE;
        } elseif (!ereg('^[[:digit:]]+$', $iHorasDuracion)) {
            $this->errMsg = 'Conference duration (hours) must be numeric and positive integer.';
            return FALSE;
        } elseif ($iHorasDuracion <= 0) {
            $this->errMsg = 'Conference duration (hours) may not be zero or negative.';
            return FALSE;
        }

        $sqlCrearConf = 
            'INSERT INTO conferencia (nombre, fecha_inicio, fecha_final, tema, id_cbmysql_conference, user) '.
            'VALUES (?, ?, ?, ?, ?, ?)';
        $iTimestamp = time();
        $sFechaInicio = date('Y-m-d H:i:s', $iTimestamp);
        $sFechaFinal = date('Y-m-d H:i:s', $iTimestamp + $iHorasDuracion * 3600);
        $result = $this->_DB->genQuery($sqlCrearConf, array($sNombre, $sFechaInicio, $sFechaFinal, $sTema, $id_cbmysql_conference, $_SESSION['elastix_user']));
        if (!$result) {
            $this->errMsg = 'Unable to create new conference - '.$this->_DB->errMsg;
            return FALSE;
        } else {
            // Recuperar el ID de conferencia recién creado
            $sqlIdConf = 
                'SELECT id_conferencia FROM conferencia '.
                'WHERE nombre = ? AND fecha_inicio = ? AND fecha_final = ? '.
                    'AND tema = ? '.
                'ORDER BY id_conferencia DESC';
            $tupla = $this->_DB->getFirstRowQuery($sqlIdConf, FALSE,
                array($sNombre, $sFechaInicio, $sFechaFinal, $sTema));
            if (!is_array($tupla)) {
                $result = FALSE;
                $this->errMsg = 'Unable to recover ID for new conference - '.$this->_DB->errMsg;                
            } elseif (count($tupla) <= 0) {
                $result = FALSE;
                $this->errMsg = '(internal) Could not find newly created conference!';                
            } else {
                $idConf = $tupla[0];
            }
        }
        return TRUE;
    }

    function getConfIDFromMeetmeID($id_cbmysql_conference)
    {
        $idConf = NULL;
        $sqlIdConf = 'SELECT id_conferencia FROM conferencia WHERE id_cbmysql_conference = ?';
        $tupla = $this->_DB->getFirstRowQuery($sqlIdConf, FALSE, array($id_cbmysql_conference));
        if (!is_array($tupla)) {
            $this->errMsg = 'Unable to recover ID for  conference - '.$this->_DB->errMsg;
        } elseif (count($tupla) <= 0) {
            $this->errMsg = 'Could not find conference!';
        } else {
            $idConf = $tupla[0];
        }
        return $idConf;
    }

    // Procedimiento que intenta crear una conexión MySQL a la base de datos MeetMe
    private function _connectMeetmeDatabase()
    {
        include_once "libs/paloSantoConfig.class.php";

        $pConfig = new paloConfig("/etc", "amportal.conf", "=", "[[:space:]]*=[[:space:]]*");
        $arrConfig = $pConfig->leer_configuracion(false);

        if (!is_array($arrConfig)) {
            $this->errMsg = '/etc/amportal.conf not found or invalid';
            return NULL;
        }
        $dsnMeetme =  $arrConfig['AMPDBENGINE']['valor'] . "://".
                      $arrConfig['AMPDBUSER']['valor'] . ":". 
                      $arrConfig['AMPDBPASS']['valor'] . "@".
                      $arrConfig['AMPDBHOST']['valor'] . "/meetme";
        $pDB     = new paloDB($dsnMeetme);
        if ($pDB->connStatus) {
            $this->errMsg = $pDB->errMsg;
            return NULL;
        }
        return $pDB;
    }

    /**
     * Procedimiento que verifica que la base de datos de MeetMe de cbmysql existe
     * y se puede conectar correctamente.
     *
     * @return bool VERDADERO si no ocurre error alguno, FALSE si error
     */
    function testMeetmeDatabase()
    {
        $testConn = $this->_connectMeetmeDatabase();
        if (!is_null($testConn)) {
            $testConn->disconnect();
            $testConn->conn = NULL;
            return TRUE;
        }
        return FALSE;
    }

    /**
     * Procedimiento que intenta crear una conferencia de voz paralela a la
     * conferencia
     * CB: Se agrega el id de la conferencia para poder borrarlo el registro en caso de
     * que el cuarto de conferencia telefonica este duplicada.
     */
    function crearConferenciaTelefonica($sNombre, $iHorasDuracion, $iNumTelefono,$idConf)
    {
        $pDB = $this->_connectMeetmeDatabase();
        if (is_null($pDB)) return FALSE;

        include_once "modules/conference/libs/paloSantoConference.php";
        $pConference = new paloSantoConference($pDB);
        
        $iTimestamp = time();
        $sFechaInicio = date('Y-m-d H:i:s', $iTimestamp);
        $sFechaFinal = date('Y-m-d H:i:s', $iTimestamp + $iHorasDuracion * 3600);
        
        //CB for fix issue - Phone number active
        $ret=$pConference->ConferenceNumberExistDateRange($iNumTelefono,$sFechaInicio);
        if($ret){
          $this->errMsg = "[{$iNumTelefono}] Phone number for phone conference is currently used. Please use other.";
          $bExito = $this->deleteConference($idConf);
          return null;          
        }
        //CB - END
        $result = $pConference->CreateConference($sNombre, $iNumTelefono, 
            $sFechaInicio, $iHorasDuracion * 3600,
            10, // TODO: leer número de invitados
            array(
                'confOwner' =>  $_SESSION['elastix_user'],
            ));        
        if (!$result) {
            $this->errMsg = 'Voice conference creation failed.';
        }
        return $result;
    }

    function existeroomNo($roomNo)
    {
        $pDB = $this->_connectMeetmeDatabase();
        if (is_null($pDB)) return FALSE;
        $sql = "select roomNo from booking";
        $result=$pDB->fetchTable($sql, true);
        foreach($result as $key => $value)
            if($value['roomNo'] == $roomNo)
                return true;
        return false;
    }

    /**
     * Método para listar todas las conferencias activas en el sistema.
     *
     * @param void
     *
     * @return NULL en error, o lista de tuplas [id_conferencia, nombre, tema]
     */
    function listarConferenciasActivas()
    {
        $listaOpcionesConf = NULL;
        $sqlConferencias = 
            'SELECT id_conferencia, nombre, tema FROM conferencia '.
            'WHERE fecha_inicio <= ? AND fecha_final > ? '.
            'ORDER BY nombre';
        $sFechaHoy = date('Y-m-d H:i:s');
        $listaConf = $this->_DB->fetchTable($sqlConferencias, FALSE, array($sFechaHoy, $sFechaHoy));

        if (is_array($listaConf)) {
            $listaOpcionesConf = array();
            foreach ($listaConf as $tuplaConf) {
                $listaOpcionesConf[$tuplaConf[0]] = "$tuplaConf[1] - $tuplaConf[2]";
            }            
        } else {
            $listaConf = NULL;
            $this->errMsg = "Unable to fetch conference list - ".$this->_DB->errMsg;
            //print $this->errMsg;
        }
        return $listaOpcionesConf;
    }

    /**
     * Procedimiento para agregar el invitado a la conferencia
     *
     * @param   $idConf     int         ID de la conferencia
     * @param   $sEmail     string      Correo electrónico del invitado, único para conferencia.
     * @param   $sPassword  string      Clave de acceso. Si es NULL, se autogenera.
     * @param   $sNick      string      Nombre opcional del usuario para mostrar en conferencia.
     * @param   $idInvitado int(OUT)    ID del nuevo invitado creado
     *
     * @return  bool    VERDADERO en éxito, FALSO en error.  
     */
    function agregarInvitadoConferencia($idConf, $sEmail, $sPassword, $sNick, &$idInvitado)
    {
        if (!ereg('^[[:digit:]]+$', $idConf)) {
            $this->errMsg = '(internal) Invalid conference ID';
            return FALSE;
        }
        // Verificar ID de conferencia
        $sql = 'SELECT COUNT(*) FROM conferencia WHERE id_conferencia = ?';
        $tupla = $this->_DB->getFirstRowQuery($sql, FALSE, array($idConf));
        if (!is_array($tupla)) {
            $this->errMsg = 'Unable to verify conference - '.$this->_DB->errMsg;
            return FALSE;
        } elseif ($tupla[0] <= 0) {
            $this->errMsg = 'Conference not found by ID';
            return FALSE;
        }

        // Verificar correo válido
        $sEregCorreo = "^[a-z0-9]+([\._\-]?[a-z0-9]+[_\-]?)*@[a-z0-9]+([\._\-]?[a-z0-9]+)*(\.[a-z0-9]{2,4})+$";
        if (!ereg($sEregCorreo, $sEmail)) {
            $this->errMsg = 'Invalid E-Mail address';
            return FALSE;
        }

        // Verificar correo duplicado
        $sql = 'SELECT COUNT(*) FROM invitado WHERE id_conferencia = ? AND email = ?';
        $tupla = $this->_DB->getFirstRowQuery($sql, FALSE, array($idConf, $sEmail));
        if (!is_array($tupla)) {
            $this->errMsg = 'Unable to verify email duplicity - '.$this->_DB->errMsg;
            return FALSE;
        } elseif ($tupla[0] > 0) {
            $this->errMsg = 'Duplicate E-Mail notification in guest list.';
            return FALSE;
        }
        
        // Autogenerar la clave de acceso
        if (is_null($sPassword)) $sPassword = substr(md5(date('Y-m-d H:i:s').$sEmail.$idConf), 0, 10);
        if (!is_null($sNick) && trim($sNick) == '') $sNick = NULL;
        $sql = 
            'INSERT INTO invitado (id_conferencia, nick, email, password, es_creador, es_presentador, logoneado) '.
            'VALUES (?, ?, ?, ?, 0, 0, 0)';
        $result = $this->_DB->genQuery($sql, array($idConf, $sNick, $sEmail, $sPassword));
        if (!$result) {
            $this->errMsg = "Unable to add user to conference - ".$this->_DB->errMsg;
            return FALSE;
        } else {
            // Leer el ID de invitado recién generado
            $sql = 'SELECT id_invitado FROM invitado WHERE id_conferencia = ? AND email = ? AND password = ? ORDER BY id_invitado DESC';
            $tupla = $this->_DB->getFirstRowQuery($sql, FALSE, array($idConf, $sEmail, $sPassword));
            if (!is_array($tupla)) {
                $this->errMsg = 'Unable to verify email duplicity - '.$this->_DB->errMsg;
                return FALSE;
            } else {
                $idInvitado = $tupla[0];
                return TRUE;
            }            
        }
    }

    /**
     * Método que lee la información del invitado desde la base de datos
     *
     * @param   $idConf int     ID de la conferencia
     * @param   $idInvitado mixed ID del invitado, o su email
     *
     * @return  mixed   Tupla de propiedades del invitado, o NULL si error o no existe
     */
    function leerInvitadoConferencia($idConf, $idInvitado)
    {
        if (!ereg('^[[:digit:]]+$', $idConf)) {
            $this->errMsg = 'Invalid conference ID';
            return NULL;
        }
        $sql = 'SELECT * FROM invitado WHERE id_conferencia = ? AND id_invitado = ?';
        if (!ereg('^[[:digit:]]+$', $idInvitado)) {
            $sql = 'SELECT * FROM invitado WHERE id_conferencia = ? AND email = ?';
        }
        $tupla = $this->_DB->getFirstRowQuery(
            $sql,
            TRUE,
            array($idConf, $idInvitado));
        if (!is_array($tupla)) {
            $this->errMsg = 'Unable to read guest info - '.$this->_DB->errMsg;
            return NULL;
        } elseif (count($tupla) <= 0) {
            $this->errMsg = 'Unable read guest info - Guest not found by ID';
            return NULL;
        } else {
            return $tupla;
        }
    }

    /**
     * Método que marca al invitado como el creador de la conferencia.
     *
     * @param   $idConf int     ID de la conferencia
     * @param   $idInvitado int ID del invitado
     *
     * @return  bool    VERDADERO en éxito, FALSO en error     
     */
    function marcarInvitadoCreador($idConf, $idInvitado)
    {
        if (!ereg('^[[:digit:]]+$', $idConf)) {
            $this->errMsg = 'Invalid conference ID';
            return FALSE;
        }
        $sqlArray = array(
            'UPDATE invitado SET es_creador = 0 WHERE id_conferencia = ? AND id_invitado <> ?',
            'UPDATE invitado SET es_creador = 1 WHERE id_conferencia = ? AND id_invitado = ?'
        );
        foreach ($sqlArray as $sql) {
            $result = $this->_DB->genQuery($sql, array($idConf, $idInvitado));
            if (!$result) {
                $this->errMsg = 'Unable to set guest as creator - '.$this->_DB->errMsg;
                return FALSE;
            }
        }
        return TRUE;
    }

    /**
     * Método que marca al invitado como el presentador de la conferencia.
     *
     * @param   $idConf int     ID de la conferencia
     * @param   $idInvitado int ID del invitado
     *
     * @return  bool    VERDADERO en éxito, FALSO en error     
     */
    function marcarInvitadoPresentador($idConf, $idInvitado)
    {
        if (!ereg('^[[:digit:]]+$', $idConf)) {
            $this->errMsg = 'Invalid conference ID';
            return FALSE;
        }
        $sqlArray = array(
            'UPDATE invitado SET es_presentador = 0 WHERE id_conferencia = ? AND id_invitado <> ?',
            'UPDATE invitado SET es_presentador = 1 WHERE id_conferencia = ? AND id_invitado = ?'
        );
        foreach ($sqlArray as $sql) {
            $result = $this->_DB->genQuery($sql, array($idConf, $idInvitado));
            if (!$result) {
                $this->errMsg = 'Unable to set guest as presentator - '.$this->_DB->errMsg;
                return FALSE;
            }
        }
        return TRUE;
    }

    /**
     * Método que marca al invitado como el presentador de la conferencia.
     *
     * @param   $idConf int     ID de la conferencia
     * @param   $idInvitado int ID del invitado
     * @param   $bEstado    BOOL    VERDADERO si logoneado, FALSO si no
     *
     * @return  bool    VERDADERO en éxito, FALSO en error     
     */
    function marcarInvitadoLogin($idConf, $idInvitado, $bEstado)
    {
        if (!ereg('^[[:digit:]]+$', $idConf)) {
            $this->errMsg = 'Invalid conference ID';
            return FALSE;
        }
        $sqlArray = array(
            'UPDATE invitado SET logoneado = ?, fecha_ultima_actividad = ? WHERE id_conferencia = ? AND id_invitado = ?',
        );
        $bEstado = $bEstado ? 1 : 0;
        foreach ($sqlArray as $sql) {
            $result = $this->_DB->genQuery($sql, array($bEstado, date('Y-m-d H:i:s'), $idConf, $idInvitado));
            if (!$result) {
                $this->errMsg = 'Unable to update login status - '.$this->_DB->errMsg;
                return FALSE;
            }
        }
        return TRUE;
    }

    /**
     * Método que actualizar el nick del invitado según lo que se elija en login.
     *
     * @param   $idConf int     ID de la conferencia
     * @param   $idInvitado int ID del invitado
     * @param   $sNick  string  Nuevo nombre del invitado
     *
     * @return  bool    VERDADERO en éxito, FALSO en error     
     */
    function actualizarNickInvitado($idConf, $idInvitado, $sNick)
    {
        if (!ereg('^[[:digit:]]+$', $idConf)) {
            $this->errMsg = 'Invalid conference ID';
            return FALSE;
        }
        $sqlArray = array(
            'UPDATE invitado SET nick = ? WHERE id_conferencia = ? AND id_invitado = ?',
        );
        foreach ($sqlArray as $sql) {
            $result = $this->_DB->genQuery($sql, array($sNick, $idConf, $idInvitado));
            if (!$result) {
                $this->errMsg = 'Unable to set new guest nick - '.$this->_DB->errMsg;
                return FALSE;
            }
        }
        return TRUE;
    }

    /**
     * Método para remover un invitado de la conferencia.
     *
     * @param   $idConf int     ID de la conferencia
     * @param   $idInvitado int ID del invitado
     *
     * @return  bool    VERDADERO en éxito, FALSO en error     
     */
    function removerInvitadoConferencia($idConf, $idInvitado)
    {
        if (!ereg('^[[:digit:]]+$', $idConf)) {
            $this->errMsg = 'Invalid conference ID';
            return FALSE;
        }
/*        $sqlRemover = 'DELETE FROM invitado WHERE id_conferencia = ? AND id_invitado = ?';*/
        $sqlRemover = 'UPDATE invitado SET fecha_cierre = ? WHERE id_conferencia = ? AND id_invitado = ? AND fecha_cierre IS NULL';
        $result = $this->_DB->genQuery($sqlRemover, array(date('Y-m-d H:i:s'), $idConf, $idInvitado));
        if (!$result) {
            $this->errMsg = "Unable to remove user from conference - ".$this->_DB->errMsg;
        }
        return $result;
    }
    
    function enviarCorreoInvitacion($idConf, $idInvitado = NULL, $sNumConferencia = NULL)
    {
        if (!ereg('^[[:digit:]]+$', $idConf)) {
            $this->errMsg = 'Invalid conference ID';
            return FALSE;
        }

        // Buscar el número de conferencia que se debe de manejar
        $sNumeroConferencia = 'unknown';
        $sArchivoConf = '/etc/asterisk/extensions_custom.conf';
        $hArchivo = @fopen($sArchivoConf, 'r');
        if ($hArchivo) {
            $bSeccionConf = FALSE;
            while (!feof($hArchivo)) {
                $s = fgets($hArchivo);
                $regs = NULL;
                if (ereg('^[[:space:]]*\[conferences\].*', $s)) $bSeccionConf = TRUE;
                if ($bSeccionConf && ereg('^[[:space:]]*exten[[:space:]]*=>[[:space:]]*([[:digit:]]+)', $s, $regs)) {
                    $sNumeroConferencia =  $regs[1];
                    break;
                }
            }
            fclose($hArchivo);
        }

        $sDominioWeb = `hostname`;  // TODO: mejorar recoger dominio web.
        $sDominioWeb = trim($sDominioWeb);
		$sDominioCorreo = $sDominioWeb;
		$regs = NULL;
		if (ereg('^www\.(.*)$', $sDominioCorreo, $regs)) $sDominioCorreo = $regs[1];

        if (!is_null($idInvitado) && !ereg('^[[:digit:]]+$', "$idInvitado")) {
            $this->errMsg = 'Invalid guest ID';
            return FALSE;
        }

        // Leer el número de la conferencia telefónica, si existe
        if (is_null($sNumConferencia)) {
            // Averiguar el ID de MySQL de la conferencia telefónica
            $sql = 'SELECT id_cbmysql_conference FROM conferencia WHERE id_conferencia = ?';
            $tupla =& $this->_DB->getFirstRowQuery($sql, FALSE, array($idConf));
            if (is_array($tupla) && count($tupla) > 0) {
                $id_cbmysql_conference = $tupla[0];
                // Conectarse a la base de datos de meetme
                include_once "libs/paloSantoConfig.class.php";

                $pConfig = new paloConfig("/etc", "amportal.conf", "=", "[[:space:]]*=[[:space:]]*");
                $arrConfig = $pConfig->leer_configuracion(false);

                $dsnMeetme =  $arrConfig['AMPDBENGINE']['valor'] . "://".
                              $arrConfig['AMPDBUSER']['valor'] . ":". 
                              $arrConfig['AMPDBPASS']['valor'] . "@".
                              $arrConfig['AMPDBHOST']['valor'] . "/meetme";
                $pDB     = new paloDB($dsnMeetme);

                $sql = 'SELECT roomNo FROM booking WHERE bookId = ?';
                $tupla =& $pDB->getFirstRowQuery($sql, FALSE, array($id_cbmysql_conference));
                if (is_array($tupla) && count($tupla) > 0) {
                    $sNumConferencia = $tupla[0];
                }
            }
        }

        // Leer la información de todos los invitados de la conferencia
        $sql = 
            'SELECT conferencia.nombre, conferencia.tema, '.
                'conferencia.fecha_inicio, conferencia.fecha_final, '.
                'invitado.nick, invitado.email, invitado.password, invitado.id_invitado '.
            'FROM conferencia, invitado '.
            'WHERE conferencia.id_conferencia = invitado.id_conferencia '.
                'AND conferencia.id_conferencia = ?';
        $sqlParams = array($idConf);
        if (!is_null($idInvitado)) {
            $sql .= ' AND invitado.id_invitado = ?';
            $sqlParams[] = $idInvitado;
        }
        $recordset = $this->_DB->fetchTable(
            $sql,
            TRUE, $sqlParams);
        if (!is_array($recordset)) {
            $this->errMsg = 'Unable to fetch guests for e-mail contacting - '.$this->_DB->errMsg;
            return FALSE;
        } elseif (count($recordset) <= 0) {
            $this->errMsg = 'No guests are available for e-mail contacting.';
            return FALSE;
        } else {
            $sFrom = "Conference Invitation <conference@$sDominioWeb>";
            $sCabeceras = 
			    "X-Mailer: PHP/".phpversion()."\r\n".
			    "From: $sFrom\r\n" .
			    "Reply-To: noreply@$sDominioCorreo\r\n" .
			    "MIME-Version: 1.0\r\n" .
			    "Content-type: text/html; charset=iso-8859-1\r\n" .
			    "Content-Transfer-Encoding: 7bit"
			    ;
            foreach ($recordset as $tuplaContacto) {
                $sURL = "https://$sDominioWeb/conference.php?conference_id=$idConf&id_user=".$tuplaContacto['id_invitado'];

                $sMensajeVoz = '';
                if (!is_null($sNumConferencia)) {
                    $sMensajeVoz = <<<MENSAJE_VOZ
<p>In addition, a voice conference has been created. To enter it, dial into the 
server with the conference number $sNumeroConferencia, and then dial the selected conference number.</p>

<p>The voice conference number is:</p>
<p>$sNumConferencia</p>

MENSAJE_VOZ;
                }


                $sMensaje = <<<MENSAJE_INVITACION
<html>
<style>
body {
    FONT-FAMILY: verdana, arial, helvetica, sans-serif;
    FONT-SIZE: 11pt
}
</style>
<head><title>Invitation to Conference</title></head>
<body>
<p>Please do not reply directly to this message</p>
<p>You have been invited to a conference in the Elastix Server at $sDominioWeb. 
To enter this conference, please follow the following link: <a href="$sURL">Enter Conference</a>
and enter your preferred nick (or leave the default one) and your generated password.</p>

<p>Your password for this conference is:</p>
<p>$tuplaContacto[password]</p>
$sMensajeVoz
<p>The conference runs from $tuplaContacto[fecha_inicio] until $tuplaContacto[fecha_final].
<hr />
<p><i>Message sent by $sDominioWeb conference invitation process.</i></p>
</body>
</html>
MENSAJE_INVITACION;
                mail(
                    $tuplaContacto['email'], 
                    "Invitation to Elastix Conference at $sDominioWeb",
                    $sMensaje,
                    $sCabeceras, 
                    "-r admin@$sDominioCorreo");
            }
            return TRUE;
        }
    }
    
    function deleteConference($idConf)
    {
        if (!ereg('^[[:digit:]]+$', $idConf)) {
            $this->errMsg = 'Invalid conference ID';
            return FALSE;
        }

        // Paso 1: borrar todos los documentos de la conferencia
        $sql = 'SELECT ruta_directorio_imgs FROM documento WHERE id_conferencia = ?';
        $listaDir = $this->_DB->fetchTable($sql, FALSE, array($idConf));
        if (!is_array($listaDir)) {
            $this->errMsg = 'Unable to list documents to delete - '.$this->_DB->errMsg;
            return FALSE;
        }
        foreach ($listaDir as $tuplaDir) {
            // TODO: verificar resultado de exec
            exec('rm -rf '.escapeshellarg($tuplaDir[0]));
        }
        $sql = 'DELETE FROM presentacion WHERE id_conferencia = ?';
        $result = $this->_DB->genQuery($sql, array($idConf));
        if (!$result) {
            $this->errMsg = "Unable to remove presentation from conference - ".$this->_DB->errMsg;
            return FALSE;
        }
        $sql = 'DELETE FROM documento WHERE id_conferencia = ?';
        $result = $this->_DB->genQuery($sql, array($idConf));
        if (!$result) {
            $this->errMsg = "Unable to remove document from conference - ".$this->_DB->errMsg;
            return FALSE;
        }

        // Paso 2: remover chatlog
        $sql = 'DELETE FROM chatlog WHERE id_conferencia = ?';
        $result = $this->_DB->genQuery($sql, array($idConf));
        if (!$result) {
            $this->errMsg = "Unable to remove chatlog from conference - ".$this->_DB->errMsg;
            return FALSE;
        }

        // Paso 3: remover invitados
        $sql = 'DELETE FROM invitado WHERE id_conferencia = ?';
        $result = $this->_DB->genQuery($sql, array($idConf));
        if (!$result) {
            $this->errMsg = "Unable to remove guests from conference - ".$this->_DB->errMsg;
            return FALSE;
        }

        // Paso 4: remover conferencia en sí
        $sql = 'DELETE FROM conferencia WHERE id_conferencia = ?';
        $result = $this->_DB->genQuery($sql, array($idConf));
        if (!$result) {
            $this->errMsg = "Unable to remove conference - ".$this->_DB->errMsg;
            return FALSE;
        }
        return TRUE;
    }
}
?>
