<?php
  /* vim: set expandtab tabstop=4 softtabstop=4 shiftwidth=4:
  Codificación: UTF-8
  +----------------------------------------------------------------------+
  | Elastix version 1.6-5                                               |
  | http://www.elastix.org                                               |
  +----------------------------------------------------------------------+
  | Copyright (c) 2006 Palosanto Solutions S. A.                         |
  +----------------------------------------------------------------------+
  | Cdla. Nueva Kennedy Calle E 222 y 9na. Este                          |
  | Telfs. 2283-268, 2294-440, 2284-356                                  |
  | Guayaquil - Ecuador                                                  |
  | http://www.palosanto.com                                             |
  +----------------------------------------------------------------------+
  | The contents of this file are subject to the General Public License  |
  | (GPL) Version 2 (the "License"); you may not use this file except in |
  | compliance with the License. You may obtain a copy of the License at |
  | http://www.opensource.org/licenses/gpl-license.php                   |
  |                                                                      |
  | Software distributed under the License is distributed on an "AS IS"  |
  | basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See  |
  | the License for the specific language governing rights and           |
  | limitations under the License.                                       |
  +----------------------------------------------------------------------+
  | The Original Code is: Elastix Open Source.                           |
  | The Initial Developer of the Original Code is PaloSanto Solutions    |
  +----------------------------------------------------------------------+
  $Id: paloSantoCreateConference.class.php,v 1.1 2009-06-29 08:06:40 Alex Villacís Lasso a_villacis@palosanto.com Exp $ */

class paloSantoListConference {
    var $_DB;
    var $errMsg;

    function paloSantoListConference(&$pDB)
    {
        // Se recibe como parámetro una referencia a una conexión paloDB
        if (is_object($pDB)) {
            $this->_DB =& $pDB;
            $this->errMsg = $this->_DB->errMsg;
        } else {
            $dsn = (string)$pDB;
            $this->_DB = new paloDB($dsn);

            if (!$this->_DB->connStatus) {
                $this->errMsg = $this->_DB->errMsg;
                // debo llenar alguna variable de error
            } else {
                // debo llenar alguna variable de error
            }
        }
    }

    /**
     * Procedimiento para listar todas las conferencias que han sido creadas, 
     * con horarios de inicio y de final, nombre y tema, y cuántos invitados 
     * contiene la conferencia
     *
     * @param   $bSoloActivas   bool    VERDADERO si sólo deben listarse conferencias activas
     * @param   $limit          integer El limite para el where sirve para uso de la paginación
     * @param   $offset         integer El offset para el where sirve para uso de la paginación
     *
     * @return mixed    NULL en error, o lista de las conferencias
     */ 
    function listarConferencias($isUserAdministratorGroup, $bSoloActivas = FALSE, $limit=NULL, $offset=NULL)
    {
        $user = ($isUserAdministratorGroup) ? '1' : 'conferencia.user = ?';
        $where = "";
        if(isset($limit) && isset($offset))
            $where = " LIMIT $limit OFFSET $offset ";
        $sql = 
            'SELECT conferencia.id_conferencia AS id_conferencia, fecha_inicio, fecha_final, nombre, tema, id_cbmysql_conference, '.
                'count(id_invitado) AS num_invitados '.
            'FROM conferencia '.
            'LEFT JOIN invitado ON conferencia.id_conferencia = invitado.id_conferencia AND invitado.fecha_cierre IS NULL '.
            "WHERE $user ".
            ($bSoloActivas ? (' AND fecha_inicio <= "'.date('Y-m-d H:i:s').'" AND fecha_final >= "'.date('Y-m-d H:i:s').'"') : '').
            'GROUP BY conferencia.id_conferencia '.
            'ORDER BY fecha_inicio, fecha_final'.$where;
        $arrParam = ($isUserAdministratorGroup) ? NULL : array($_SESSION['elastix_user']);
        $recordset = $this->_DB->fetchTable($sql, TRUE, $arrParam);
        if (!is_array($recordset)) {
            $this->errMsg = 'Could not list conferences - '.$this->_DB->errMsg;
            $recordset = NULL;
        } else {
            foreach ($recordset as $key => $tupla) {
                $sql = 'SELECT COUNT(*) FROM documento WHERE id_conferencia = ?';
                $t = $this->_DB->getFirstRowQuery($sql, FALSE, array($tupla['id_conferencia']));
                if (!is_array($t))
                    $recordset[$key]['num_documentos'] = 0;
                else $recordset[$key]['num_documentos'] = $t[0];
            }
        }
        return $recordset;
    }

/**
     * Procedimiento para obtener el numero de registros de las lista de conferencias a mostrar
     *
     * @param   $bSoloActivas   bool    VERDADERO si sólo deben listarse conferencias activas
     *
     * @return mixed    NULL en error, o lista de las conferencias
     */ 
    function getNumListarConferencias($isUserAdministratorGroup, $bSoloActivas = FALSE)
    {
        $user = ($isUserAdministratorGroup) ? '1' : 'conferencia.user = ?';
        $sql = 
            'SELECT conferencia.id_conferencia AS id_conferencia, fecha_inicio, fecha_final, nombre, tema, id_cbmysql_conference, '.
                'count(id_invitado) AS num_invitados '.
            'FROM conferencia '.
            'LEFT JOIN invitado ON conferencia.id_conferencia = invitado.id_conferencia AND invitado.fecha_cierre IS NULL '.
            "WHERE $user ".
            ($bSoloActivas ? (' AND fecha_inicio <= "'.date('Y-m-d H:i:s').'" AND fecha_final >= "'.date('Y-m-d H:i:s').'"') : '').
            'GROUP BY conferencia.id_conferencia '.
            'ORDER BY fecha_inicio, fecha_final';
        $arrParam = ($isUserAdministratorGroup) ? NULL : array($_SESSION['elastix_user']);
        $recordset = $this->_DB->fetchTable($sql, TRUE, $arrParam);
        if (!is_array($recordset)) {
            $this->errMsg = 'Could not list conferences - '.$this->_DB->errMsg;
            $recordset = NULL;
        } else {
            foreach ($recordset as $key => $tupla) {
                $sql = 'SELECT COUNT(*) FROM documento WHERE id_conferencia = ?';
                $t = $this->_DB->getFirstRowQuery($sql, FALSE, array($tupla['id_conferencia']));
                if (!is_array($t))
                    $recordset[$key]['num_documentos'] = 0;
                else $recordset[$key]['num_documentos'] = $t[0];
            }
        }
        return count($recordset);
    }

    /**
     * Procedimiento para leer la información de una sola conferencia
     * @param   $idConf int ID de la conferencia a listar
     *
     * @return mixed    NULL en error, o información de la conferencia
     */
    function leerConferencia($idConf)
    {
        if (!ereg('^[[:digit:]]+$', "$idConf")) {
            $this->errMsg = 'Invalid conference ID';
            return NULL;
        }
        $sql = 
            'SELECT id_conferencia, fecha_inicio, fecha_final, nombre, tema '.
            'FROM conferencia '.
            'WHERE id_conferencia = ?';
        $tupla = $this->_DB->getFirstRowQuery($sql, TRUE, array($idConf));
        if (!is_array($tupla)) {
            $this->errMsg = 'Unable to read conference information - '.$this->_DB->errMsg;
            return NULL;
        } elseif (count($tupla) == 0) {
            $this->errMsg = 'Conference not found by ID';
            return NULL;
        } else {
            return $tupla;
        }
    }

    /**
     * Procedimiento para listar todos los invitados de una conferencia creada.
     * @param   $idConf int ID de la conferencia a listar
     *
     * @return mixed    NULL en error, o lista de los invitados a la conferencia
     */
    function listarInvitadosConferencia($idConf)
    {
        if (!ereg('^[[:digit:]]+$', "$idConf")) {
            $this->errMsg = 'Invalid conference ID';
            return NULL;
        }
        $sql = 
            'SELECT id_invitado, nick, email, es_creador, es_presentador, logoneado, fecha_ultima_actividad '.
            'FROM invitado WHERE id_conferencia = ? AND fecha_cierre IS NULL ORDER BY email';
        $recordset = $this->_DB->fetchTable($sql, TRUE, array($idConf));
        if (!is_array($recordset)) {
            $this->errMsg = 'Could not list guests for conference - '.$this->_DB->errMsg;
            $recordset = NULL;
        }
        return $recordset;
    }

    function listarid_conferenceforUser($user)
    {
        $sql = "select id_conferencia from conferencia where user=?";
        $arrParam = array($user);
        $recordset = $this->_DB->fetchTable($sql, TRUE, $arrParam);
        if (!is_array($recordset)) {
            $this->errMsg = "Could not list id_conferencia for user: $user - ".$this->_DB->errMsg;
            $recordset = NULL;
        }
        return $recordset;
    }
}
?>
