<?php
  /* vim: set expandtab tabstop=4 softtabstop=4 shiftwidth=4:
  Codificación: UTF-8
  +----------------------------------------------------------------------+
  | Elastix version 1.6-5                                               |
  | http://www.elastix.org                                               |
  +----------------------------------------------------------------------+
  | Copyright (c) 2006 Palosanto Solutions S. A.                         |
  +----------------------------------------------------------------------+
  | Cdla. Nueva Kennedy Calle E 222 y 9na. Este                          |
  | Telfs. 2283-268, 2294-440, 2284-356                                  |
  | Guayaquil - Ecuador                                                  |
  | http://www.palosanto.com                                             |
  +----------------------------------------------------------------------+
  | The contents of this file are subject to the General Public License  |
  | (GPL) Version 2 (the "License"); you may not use this file except in |
  | compliance with the License. You may obtain a copy of the License at |
  | http://www.opensource.org/licenses/gpl-license.php                   |
  |                                                                      |
  | Software distributed under the License is distributed on an "AS IS"  |
  | basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See  |
  | the License for the specific language governing rights and           |
  | limitations under the License.                                       |
  +----------------------------------------------------------------------+
  | The Original Code is: Elastix Open Source.                           |
  | The Initial Developer of the Original Code is PaloSanto Solutions    |
  +----------------------------------------------------------------------+
  $Id: paloSantoPresentation.class.php,v 1.1 2009-06-29 08:06:36 Alex Villacís Lasso a_villacis@palosanto.com Exp $ */
class paloSantoPresentation {
    var $_DB;
    var $errMsg;

    function paloSantoPresentation(&$pDB)
    {
        // Se recibe como parámetro una referencia a una conexión paloDB
        if (is_object($pDB)) {
            $this->_DB =& $pDB;
            $this->errMsg = $this->_DB->errMsg;
        } else {
            $dsn = (string)$pDB;
            $this->_DB = new paloDB($dsn);

            if (!$this->_DB->connStatus) {
                $this->errMsg = $this->_DB->errMsg;
                // debo llenar alguna variable de error
            } else {
                // debo llenar alguna variable de error
            }
        }
    }

    function getPresentationInfo($idConf)
    {
        $sqlInfoPresentacion = 
            'SELECT presentacion.pag_actual AS pag_actual, documento.* '.
            'FROM presentacion, documento '.
            'WHERE presentacion.id_conferencia = documento.id_conferencia '.
                'AND presentacion.id_documento = documento.id_documento '.
                'AND presentacion.id_conferencia = ?';
        $infoDoc = $this->_DB->getFirstRowQuery(
            $sqlInfoPresentacion, 
            TRUE, array($idConf));
        if (is_array($infoDoc)) {
            if (count($infoDoc) == 0) {
                $this->errMsg = "Specified presentation does not exist.";
                $infoDoc = NULL;
            } elseif (!is_dir($infoDoc['ruta_directorio_imgs'])) {
                $this->errMsg = "Document directory is invalid.";
                $infoDoc = NULL;
            }
        } else {
            $infoDoc = NULL;
            $this->errMsg = "Unable to fetch presentation info - ".$this->_DB->errMsg;
        }
        return $infoDoc;
    }

    function getCurrentHost($idConf)
    {
        $info = $this->_DB->getFirstRowQuery(
            'SELECT id_invitado FROM invitado WHERE id_conferencia = ? AND es_creador = 1',
            FALSE, array($idConf));
        if (!is_array($info)) {
            $this->errMsg = 'Unable to query conference host - '.$this->_DB->errMsg;
            return NULL;
        }
        return count($info) > 0 ? $info[0] : NULL;
    }
    
    function getCurrentPresentator($idConf)
    {
        $info = $this->_DB->getFirstRowQuery(
            'SELECT id_invitado FROM invitado WHERE id_conferencia = ? AND es_presentador = 1',
            FALSE, array($idConf));
        if (!is_array($info)) {
            $this->errMsg = 'Unable to query conference host - '.$this->_DB->errMsg;
            return NULL;
        }
        return count($info) > 0 ? $info[0] : NULL;
    }

    function getUserList($idConf)
    {
        $recordset = $this->_DB->fetchTable(
            'SELECT * FROM invitado WHERE id_conferencia = ? ORDER BY nick',
            TRUE, array($idConf));
        if (!is_array($recordset)) {
            $this->errMsg = 'Unable to read user list for conference - '.$this->_DB->errMsg;
            return NULL;
        }
        return $recordset;
    }

    function setCurrentPresentation($idConf, $idDocument)
    {
        // Verificar que el documento realmente pertenece a la conferencia
        $tupla = $this->_DB->getFirstRowQuery(
            'SELECT COUNT(*) FROM documento '.
            'WHERE id_conferencia = ? AND id_documento = ?', FALSE, 
            array($idConf, $idDocument));
        if (!is_array($tupla)) {
            $this->errMsg = 'Unable to verify requested document - '.$this->_DB->errMsg;
            return FALSE;
        }
        if ($tupla[0] <= 0) {
            $this->errMsg = 'Selected document does not belong to conference!';
            return FALSE;
        }

        // Verificar si ya existe una presentación
        $result = FALSE;
        $tupla = $this->_DB->getFirstRowQuery(
            'SELECT id_presentacion FROM presentacion WHERE id_conferencia = ?',
            FALSE, array($idConf));
        if (!is_array($tupla)) {
            $this->errMsg = 'Unable to verify existing presentation - '.$this->_DB->errMsg;
            return FALSE;
        } elseif (count($tupla) == 0) {
            // Remover cualquier referencia anterior a documento
            $result = $this->_DB->genQuery('DELETE FROM presentacion WHERE id_conferencia = ?', array($idConf));
            if (!$result) {
                $this->errMsg = 'Unable to remove previous presentation - '.$this->_DB->errMsg;
                return FALSE;
            }
            
            // Agregar referencia a documento indicado en página 1
            $result = $this->_DB->genQuery(
                'INSERT INTO presentacion (id_documento, id_conferencia, pag_actual) '.
                'VALUES (?, ?, 1)', 
                array($idDocument, $idConf));
            if (!$result) {
                $this->errMsg = 'Unable to set new presentation - '.$this->_DB->errMsg;
                return FALSE;
            }
        } else {
            // Agregar referencia a documento indicado en página 1
            $result = $this->_DB->genQuery(
                'UPDATE presentacion SET pag_actual = 1, id_documento = ? '.
                'WHERE id_presentacion = ?', 
                array($idDocument, $tupla[0]));
            if (!$result) {
                $this->errMsg = 'Unable to set new presentation - '.$this->_DB->errMsg;
                return FALSE;
            }

        }
        
        return $result;
    }

    function selectFirstPage($idDoc)
    {
        $sqlCambioPagina = 'UPDATE presentacion SET pag_actual = 1 WHERE id_documento = ?';
        return $this->_DB->genQuery($sqlCambioPagina, array($idDoc));
    }

    function selectPrevPage($idDoc)
    {
        $sqlCambioPagina = 'UPDATE presentacion SET pag_actual = pag_actual - 1 WHERE id_documento = ? AND pag_actual > 1';
        return $this->_DB->genQuery($sqlCambioPagina, array($idDoc));
    }

    function selectNextPage($idDoc)
    {
        $sqlNumPaginas = 'SELECT num_paginas FROM documento WHERE id_documento = ?';
        $tupla = $this->_DB->getFirstRowQuery($sqlNumPaginas, FALSE, array($idDoc));
        if (!is_array($tupla) || count($tupla) <= 0) return FALSE;
        $sqlCambioPagina = 'UPDATE presentacion SET pag_actual = pag_actual + 1 WHERE id_documento = ? AND pag_actual < ?';
        return $this->_DB->genQuery($sqlCambioPagina, array($idDoc, $tupla[0]));
    }

    function selectLastPage($idDoc)
    {
        $sqlNumPaginas = 'SELECT num_paginas FROM documento WHERE id_documento = ?';
        $tupla = $this->_DB->getFirstRowQuery($sqlNumPaginas, FALSE, array($idDoc));
        if (!is_array($tupla) || count($tupla) <= 0) return FALSE;
        $sqlCambioPagina = 'UPDATE presentacion SET pag_actual = ? WHERE id_documento = ?';
        return $this->_DB->genQuery($sqlCambioPagina, array($tupla[0], $idDoc));
    }

    function selectPageByNumber($idDoc, $iPageNum)
    {
        $sqlNumPaginas = 'SELECT num_paginas FROM documento WHERE id_documento = ?';
        $tupla = $this->_DB->getFirstRowQuery($sqlNumPaginas, FALSE, array($idDoc));
        if (!is_array($tupla) || count($tupla) <= 0) return FALSE;
        $sqlCambioPagina = 'UPDATE presentacion SET pag_actual = ? WHERE id_documento = ?';
        return ereg('^[[:digit:]]+$', "$iPageNum") && $iPageNum > 0 && $iPageNum <= $tupla[0] 
            && $this->_DB->genQuery($sqlCambioPagina, array($iPageNum, $idDoc));
    }

    function handOffToUser($idConf, $sNuevoUsuario)
    {
        $result = $this->_DB->genQuery(
            'UPDATE invitado SET es_presentador = 0 WHERE id_conferencia = ?', 
            array($idConf));
        if (!$result) {
            $this->errMsg = 'Unable to deactivate current owner for presentation - '.$this->_DB->errMsg;
            return FALSE;
        }

        $result = $this->_DB->genQuery(
            'UPDATE invitado SET es_presentador = 1 WHERE id_conferencia = ? AND id_invitado = ?', 
            array($idConf, $sNuevoUsuario));
        if (!$result) {
            $this->errMsg = 'Unable to activate new owner for presentation - '.$this->_DB->errMsg;
            return FALSE;
        }
        return TRUE;
    }
}
?>
